@@ -31,7 +31,7 @@ package PDF::Kit;
 # --------------------------------------
 # Pragmas
 
-require 5.8.0;
+require v5.8.0;
 
 use strict;
 use warnings;
@@ -40,7 +40,7 @@ use utf8;  # Convert all UTF-8 to Perl's internal representation.
 
 # --------------------------------------
 # Version
-use version; our $VERSION = qv(v1.0.0);
+use version; our $VERSION = qv(v1.0.1);
 
 # --------------------------------------
 # Exports
@@ -743,7 +743,7 @@ PDF::Kit - A collection of subroutines for PDF::API2.
 
 =head1 VERSION
 
-This document refers to PDF::Kit version v1.0.0
+This document refers to PDF::Kit version v1.0.1
 
 =head1 SYNOPSIS
 
